﻿Public Class VortexConfig
    ' The form this one is configuring.
    Private FractalForm As Form1

    ' Initialize the options.
    Public Sub Initialize(ByVal frm As Form1)
        FractalForm = frm

        txtMaxIterations.Text = Format(FractalForm.MaxIterations, "0")
        txtZr.Text = Format(FractalForm.C.Re, "0.00")
        txtZim.Text = Format(FractalForm.C.Im, "0.00")

        Select Case FractalForm.ColorStyle
            Case ColorStyles.Smooth1
                radColorSmooth1.Checked = True
            Case ColorStyles.Smooth2
                radColorSmooth2.Checked = True
            Case Else
                radColorOriginal.Checked = True
        End Select

        ' Deselect all colors.
        cmdNone_Click(Nothing, Nothing)

        ' Select the colors in use by the main form.
        For i As Integer = 0 To FractalForm.NumColors - 1
            ' Select the PictureBox with this color.
            SelectColor(FractalForm.Colors(i))
        Next i
    End Sub

    ' Select all colors.
    Private Sub cmdAll_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdAll.Click
        For Each ctl As Control In Me.Controls
            If TypeOf ctl Is PictureBox Then
                Dim pic As PictureBox = DirectCast(ctl, PictureBox)
                pic.BorderStyle = BorderStyle.Fixed3D
            End If
        Next ctl
    End Sub

    ' Deselect all colors.
    Private Sub cmdNone_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdNone.Click
        For Each ctl As Control In Me.Controls
            If TypeOf ctl Is PictureBox Then
                Dim pic As PictureBox = DirectCast(ctl, PictureBox)
                pic.BorderStyle = BorderStyle.None
            End If
        Next ctl
    End Sub

    ' Select the colors in this column.
    Private Sub SelectColumn(ByVal col As Integer)
        ' Deselect all colors.
        cmdNone_Click(Nothing, Nothing)

        ' Select the colors in this column.
        Dim pic_name As String
        For i As Integer = 0 To 5
            pic_name = "picColor_" & (i * 8 + col).ToString()
            SelectPictureBox(pic_name)
        Next i
    End Sub

    ' Select the colors in this row.
    Private Sub SelectRow(ByVal row As Integer)
        ' Deselect all colors.
        cmdNone_Click(Nothing, Nothing)

        ' Select the colors in this column.
        Dim pic_name As String
        Dim first_number As Integer = row * 8
        For i As Integer = 0 To 7
            pic_name = "picColor_" & (i + first_number).ToString()
            SelectPictureBox(pic_name)
        Next i
    End Sub

    ' Select the PictureBox with this name.
    Private Sub SelectPictureBox(ByVal pic_name As String)
        Dim ctl As Control = GetControlByName(pic_name)
        Dim pic As PictureBox = DirectCast(ctl, PictureBox)
        pic.BorderStyle = BorderStyle.Fixed3D
    End Sub

    ' Select the PictureBox with this color.
    Private Sub SelectColor(ByVal clr As Color)
        For Each ctl As Control In Me.Controls
            If TypeOf ctl Is PictureBox Then
                If ctl.BackColor.Equals(clr) Then
                    Dim pic As PictureBox = DirectCast(ctl, PictureBox)
                    pic.BorderStyle = BorderStyle.Fixed3D
                    Exit Sub
                End If
            End If
        Next ctl
    End Sub

    ' Return the control with this name.
    Private Function GetControlByName(ByVal pic_name As String) As Control
        For Each ctl As Control In Me.Controls
            If ctl.Name = pic_name Then Return ctl
        Next ctl
        Return Nothing
    End Function

    Private Sub cmdColumn_0_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_0.Click
        SelectColumn(0)
    End Sub
    Private Sub cmdColumn_1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_1.Click
        SelectColumn(1)
    End Sub
    Private Sub cmdColumn_2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_2.Click
        SelectColumn(2)
    End Sub
    Private Sub cmdColumn_3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_3.Click
        SelectColumn(3)
    End Sub
    Private Sub cmdColumn_4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_4.Click
        SelectColumn(4)
    End Sub
    Private Sub cmdColumn_5_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_5.Click
        SelectColumn(5)
    End Sub
    Private Sub cmdColumn_6_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_6.Click
        SelectColumn(6)
    End Sub
    Private Sub cmdColumn_7_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdColumn_7.Click
        SelectColumn(7)
    End Sub
    Private Sub cmdRow_0_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_0.Click
        SelectRow(0)
    End Sub
    Private Sub cmdRow_1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_1.Click
        SelectRow(1)
    End Sub
    Public Sub cmdRow_2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_2.Click
        SelectRow(2)
    End Sub
    Private Sub cmdRow_3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_3.Click
        SelectRow(3)
    End Sub
    Private Sub cmdRow_4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_4.Click
        SelectRow(4)
    End Sub
    Private Sub cmdRow_5_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdRow_5.Click
        SelectRow(5)
    End Sub

    ' Apply the changes.
    Public Sub cmdOk_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdOk.Click
        AcceptSelections()
        Me.Close()
    End Sub
    Public Sub AcceptSelections()
        ' Get the number of iterations.
        FractalForm.MaxIterations = Integer.Parse(txtMaxIterations.Text)

        ' Get Z.
        FractalForm.C = New Complex( _
            Double.Parse(txtZr.Text), _
            Double.Parse(txtZim.Text))

        ' Save the selected colors.
        ' (This is a little odd because we want to save them
        ' in the order in which they appear on the dialog.)
        FractalForm.ResetColors()
        For i As Integer = 0 To 47
            ' See if this color is selected.
            Dim ctl As Control = GetControlByName("picColor_" & i)
            Dim pic As PictureBox = DirectCast(ctl, PictureBox)
            If pic.BorderStyle = BorderStyle.Fixed3D Then
                FractalForm.AddColor(pic.BackColor)
            End If
        Next i

        ' Save the selected color style.
        If (radColorOriginal.Checked) Then
            FractalForm.ColorStyle = ColorStyles.Original
        ElseIf (radColorSmooth1.Checked) Then
            FractalForm.ColorStyle = ColorStyles.Smooth1
        Else
            FractalForm.ColorStyle = ColorStyles.Smooth2
        End If
    End Sub

    ' Close the dialog without saving the changes.
    Private Sub cmdCancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdCancel.Click
        Me.Close()
    End Sub

    Private Sub cmdDefault_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdDefault.Click
        SetDefaultColors()
    End Sub
    Public Sub SetDefaultColors()
        ' Deselect everything.
        cmdNone_Click(Nothing, Nothing)

        ' Select the default colors.
        picColor_40.BorderStyle = BorderStyle.Fixed3D
        picColor_17.BorderStyle = BorderStyle.Fixed3D
        picColor_18.BorderStyle = BorderStyle.Fixed3D
        picColor_19.BorderStyle = BorderStyle.Fixed3D
        picColor_20.BorderStyle = BorderStyle.Fixed3D
        picColor_21.BorderStyle = BorderStyle.Fixed3D
        picColor_22.BorderStyle = BorderStyle.Fixed3D
        picColor_23.BorderStyle = BorderStyle.Fixed3D
    End Sub

    ' Select this color.
    Private Sub picColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles picColor_0.Click, picColor_1.Click, picColor_2.Click, picColor_3.Click, picColor_4.Click, picColor_5.Click, picColor_6.Click, picColor_7.Click, picColor_8.Click, picColor_9.Click, picColor_10.Click, picColor_11.Click, picColor_12.Click, picColor_13.Click, picColor_14.Click, picColor_15.Click, picColor_16.Click, picColor_17.Click, picColor_18.Click, picColor_19.Click, picColor_20.Click, picColor_21.Click, picColor_22.Click, picColor_23.Click, picColor_24.Click, picColor_25.Click, picColor_26.Click, picColor_27.Click, picColor_28.Click, picColor_29.Click, picColor_30.Click, picColor_31.Click, picColor_32.Click, picColor_33.Click, picColor_34.Click, picColor_35.Click, picColor_36.Click, picColor_37.Click, picColor_38.Click, picColor_39.Click, picColor_40.Click, picColor_41.Click, picColor_42.Click, picColor_43.Click, picColor_44.Click, picColor_45.Click, picColor_46.Click, picColor_47.Click
        Dim pic As PictureBox = DirectCast(sender, PictureBox)
        If pic.BorderStyle = BorderStyle.Fixed3D Then
            pic.BorderStyle = BorderStyle.None
        Else
            pic.BorderStyle = BorderStyle.Fixed3D
        End If
    End Sub
End Class